# Set working directory and read packages
setwd("D:/gee_examples/tables/ls")
library(dplyr)
library(purrr)
library(tidyr)
library(ggplot2)

# List all CSV files in working directory
files <- list.files(pattern = '\\.csv$', full.names = TRUE)

# Merge all CSV files to a single data frame
all_data <- do.call(rbind, lapply(files, function(x) 
  transform(read.csv(x), File = basename(x))))

# Create new date field and format
all_data$date2 <- substring(all_data$date, 1, 10)
all_data$date2 <- as.Date(all_data$date, "%Y-%m-%d")

# Filter dasta using pixel_qa and codes
ls8_valid <- c(322, 386, 834, 898, 1346, 324, 388, 836, 900, 1348)
# For codes see: https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-1-level-1-quality-assessment-band?qt-science_support_page_related_con=0#qt-science_support_page_related_con 
ls8_clear <- all_data %>% filter(pixel_qa %in% ls8_valid)

#Plot data for one site (NDVI)
site1 <- ls8_clear %>% filter(SiteID==1)

ggplot(site1, aes(x=date2, y=(B5-B7)/(B5+B7)))+
  geom_line()

#Write results to CSV
write.csv(ls8_clear, "D:/gee_examples/landsat_out.csv")


#Repeat for Sentinel-2 data 
setwd("D:/gee_examples/tables/s2")
library(dplyr)
library(purrr)
library(tidyr)
library(ggplot2)

files <- list.files(pattern = '\\.csv$', full.names = TRUE)

all_data <- do.call(rbind, lapply(files, function(x) 
  transform(read.csv(x), File = basename(x))))

all_data$date2 <- substring(all_data$date, 1, 10)
all_data$date2 <- as.Date(all_data$date, "%Y-%m-%d")

# For codes see: https://developers.google.com/earth-engine/datasets/catalog/COPERNICUS_S2_SR
s2_valid <- c(0)
s2_clear <- all_data %>% filter(QA60 %in% s2_valid)

site1 <- s2_clear %>% filter(SiteID==1)

ggplot(site1, aes(x=date2, y=(B8-B11)/(B8+B11)))+
  geom_line()

write.csv(s2_clear, "D:/gee_examples/sentinel2_out.csv")

